@@ -32,9 +32,9 @@ class GaussIterator(_LabeledImageIterator):
         Init.
 
         Args:
-            image_extractor:                is-a `ImageExtractor`.
-            train_csv_path:                 `str` of path to CSV file in training.
-            test_csv_path:                  `str` of path to CSV file in test.
+            loc:                            Mean (“centre”) of the distribution.
+            std:                            Scale of the distribution.
+            dim:                            Dimension.
 
             epochs:                         `int` of epochs of Mini-batch.
             batch_size:                      `int` of batch size of Mini-batch.
