@@ -208,6 +208,7 @@ class ConvolutionalAutoEncoder(ConvolutionalNeuralNetworks):
         learning_rate = self.__learning_rate
         try:
             epoch = 0
+            iter_n = 0
             for batch_observed_arr, batch_target_arr, test_batch_observed_arr, test_batch_target_arr in iteratable_data.generate_learned_samples():
                 self.epoch = epoch
                 self.batch_size = batch_observed_arr.shape[0]
@@ -226,19 +227,18 @@ class ConvolutionalAutoEncoder(ConvolutionalNeuralNetworks):
                 self.trainer.step(batch_observed_arr.shape[0])
                 self.regularize()
 
-                # rank-3
-                test_pred_arr = self.inference(test_batch_observed_arr)
+                if (iter_n+1) % int(iteratable_data.iter_n / iteratable_data.epochs) == 0:
+                    # rank-3
+                    test_pred_arr = self.inference(test_batch_observed_arr)
+                    test_loss = self.compute_loss(
+                        test_pred_arr,
+                        test_batch_target_arr
+                    )
+                    self.__loss_list.append((loss.asnumpy().mean(), test_loss.asnumpy().mean()))
 
-                test_loss = self.compute_loss(
-                    test_pred_arr,
-                    test_batch_target_arr
-                )
-
-                if (epoch + 1) % 100 == 0:
                     self.__logger.debug("Epochs: " + str(epoch + 1) + " Train loss: " + str(loss.asnumpy().mean()) + " Test loss: " + str(test_loss.asnumpy().mean()))
-
-                self.__loss_list.append((loss.asnumpy().mean(), test_loss.asnumpy().mean()))
-                epoch += 1
+                    epoch += 1
+                iter_n += 1
 
         except KeyboardInterrupt:
             self.__logger.debug("Interrupt.")
